"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelParcelforceEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | parcelforce_express48 | Express 48|
    | parcelforce_express24 | Express 24|
    | parcelforce_expressam | Express AM|
    """
    PARCELFORCE_EXPRESS48 = 'parcelforce_express48'
    PARCELFORCE_EXPRESS24 = 'parcelforce_express24'
    PARCELFORCE_EXPRESSAM = 'parcelforce_expressam'



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ParcelTemplateDHLeCommerceEnum(str, Enum):
    r"""|Token | Name | Dimensions|
    |:---|:---|:---|
    | DHLeC_Irregular | Irregular Shipment | 10.00 x 10.00 x 10.00 in|
    | DHLeC_SM_Flats | Flats | 27.00 x 17.00 x 17.00 in|
    """
    DH_LE_C_IRREGULAR = 'DHLeC_Irregular'
    DH_LE_C_SM_FLATS = 'DHLeC_SM_Flats'



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from .dangerousgoodsbiologicalmaterial import DangerousGoodsBiologicalMaterial
from .dangerousgoodslithiumbatteries import DangerousGoodsLithiumBatteries
from dataclasses_json import Undefined, dataclass_json
from shippo import utils
from typing import Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class DangerousGoodsObject:
    r"""Container for specifying the presence of dangerous materials. This is specific to USPS, and if any contents
    are provided, only certain USPS service levels will be eligible. For more information, see our
    <a href=\"https://docs.goshippo.com/docs/shipments/hazmat/\">guide on hazardous or dangerous materials shipping</a>.
    """
    contains: Optional[bool] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('contains'), 'exclude': lambda f: f is None }})
    r"""Indicates if the shipment contains dangerous goods."""
    biological_material: Optional[DangerousGoodsBiologicalMaterial] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('biological_material'), 'exclude': lambda f: f is None }})
    r"""Container for specifying the presence of biological material."""
    lithium_batteries: Optional[DangerousGoodsLithiumBatteries] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('lithium_batteries'), 'exclude': lambda f: f is None }})
    r"""Container for specifying the presence of lithium batteries."""
    




"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from shippo import utils
from typing import Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class LiveRate:
    amount: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('amount'), 'exclude': lambda f: f is None }})
    r"""Final Rate price, expressed in the currency used in the sender's country."""
    amount_local: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('amount_local'), 'exclude': lambda f: f is None }})
    r"""Final Rate price, expressed in the currency used in the recipient's country."""
    currency: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('currency'), 'exclude': lambda f: f is None }})
    r"""Currency used in the sender's country, refers to `amount`.
    The <a href=\"http://www.xe.com/iso4217.php\">official ISO 4217</a> currency codes are used, e.g. `USD` or `EUR`.
    """
    currency_local: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('currency_local'), 'exclude': lambda f: f is None }})
    r"""Currency used in the recipient's country, refers to `amount_local`.
    The <a href=\"http://www.xe.com/iso4217.php\">official ISO 4217</a> currency codes are used, e.g. `USD` or \"EUR\".
    """
    estimated_days: Optional[int] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('estimated_days'), 'exclude': lambda f: f is None }})
    r"""The estimated days in transit of the rate that powers the shipping option, if available."""
    title: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title'), 'exclude': lambda f: f is None }})
    r"""The name of the service group being returned"""
    




"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from .addresscreaterequest import AddressCreateRequest
from .customsdeclarationcreaterequest import CustomsDeclarationCreateRequest
from .parcelcreatefromtemplaterequest import ParcelCreateFromTemplateRequest
from .parcelcreaterequest import ParcelCreateRequest
from .shipmentextra import ShipmentExtra
from dataclasses_json import Undefined, dataclass_json
from shippo import utils
from typing import List, Optional, Union


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ShipmentCreateRequest:
    address_from: AddressFrom = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('address_from') }})
    address_to: AddressTo = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('address_to') }})
    parcels: List[Parcels] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('parcels') }})
    extra: Optional[ShipmentExtra] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('extra'), 'exclude': lambda f: f is None }})
    r"""An object holding optional extra services to be requested."""
    metadata: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('metadata'), 'exclude': lambda f: f is None }})
    r"""A string of up to 100 characters that can be filled with any additional information you want to attach to the object."""
    shipment_date: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('shipment_date'), 'exclude': lambda f: f is None }})
    r"""Date the shipment will be tendered to the carrier. Must be in the format `2014-01-18T00:35:03.463Z`.
    Defaults to current date and time if no value is provided. Please note that some carriers require this value to
    be in the future, on a working day, or similar.
    """
    address_return: Optional[AddressReturn] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('address_return'), 'exclude': lambda f: f is None }})
    customs_declaration: Optional[ShipmentCreateRequestCustomsDeclaration] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('customs_declaration'), 'exclude': lambda f: f is None }})
    async_: Optional[bool] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('async'), 'exclude': lambda f: f is None }})
    carrier_accounts: Optional[List[str]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('carrier_accounts'), 'exclude': lambda f: f is None }})
    r"""List of <a href=\\"#tag/Carrier-Accounts/\\">Carrier Accounts</a> `object_id`s used to filter
    the returned rates.  If set, only rates from these carriers will be returned.
    """
    


AddressFrom = Union[AddressCreateRequest, str]

AddressReturn = Union[AddressCreateRequest, str]

AddressTo = Union[AddressCreateRequest, str]

ShipmentCreateRequestCustomsDeclaration = Union[CustomsDeclarationCreateRequest, str]

Parcels = Union[ParcelCreateRequest, ParcelCreateFromTemplateRequest, str]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelCouriersPleaseEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | couriersplease_domestic_priority_auth_to_leave | Domestic Priority - Authority To Leave/POPPoints|
    | couriersplease_domestic_priority_sign_required | Domestic Priority - Signature Required|
    | couriersplease_gold_domestic_auth_to_leave | Gold Domestic - Authority To Leave/POPPoints|
    | couriersplease_gold_domestic_sign_required | Gold Domestic - Signature Required|
    | couriersplease_off_peak_auth_to_leave | Off Peak - Authority To Leave/POPPoints|
    | couriersplease_off_peak_sign_required | Off Peak - Signature Required|
    | couriersplease_parcel_auth_to_leave | Parcel - Authority To Leave|
    | couriersplease_parcel_sign_required | Parcel - Signature Required|
    | couriersplease_road_express | Road Express|
    | couriersplease_satchel_auth_to_leave | Satchel - Authority To Leave|
    | couriersplease_satchel_sign_required | Satchel - Signature Required|
    """
    COURIERSPLEASE_DOMESTIC_PRIORITY_AUTH_TO_LEAVE = 'couriersplease_domestic_priority_auth_to_leave'
    COURIERSPLEASE_DOMESTIC_PRIORITY_SIGN_REQUIRED = 'couriersplease_domestic_priority_sign_required'
    COURIERSPLEASE_GOLD_DOMESTIC_AUTH_TO_LEAVE = 'couriersplease_gold_domestic_auth_to_leave'
    COURIERSPLEASE_GOLD_DOMESTIC_SIGN_REQUIRED = 'couriersplease_gold_domestic_sign_required'
    COURIERSPLEASE_OFF_PEAK_AUTH_TO_LEAVE = 'couriersplease_off_peak_auth_to_leave'
    COURIERSPLEASE_OFF_PEAK_SIGN_REQUIRED = 'couriersplease_off_peak_sign_required'
    COURIERSPLEASE_PARCEL_AUTH_TO_LEAVE = 'couriersplease_parcel_auth_to_leave'
    COURIERSPLEASE_PARCEL_SIGN_REQUIRED = 'couriersplease_parcel_sign_required'
    COURIERSPLEASE_ROAD_EXPRESS = 'couriersplease_road_express'
    COURIERSPLEASE_SATCHEL_AUTH_TO_LEAVE = 'couriersplease_satchel_auth_to_leave'
    COURIERSPLEASE_SATCHEL_SIGN_REQUIRED = 'couriersplease_satchel_sign_required'



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ParcelTemplateUSPSEnum(str, Enum):
    r"""|Token | Name | Dimensions|
    |:---|:---|:---|
    | USPS_FlatRateCardboardEnvelope | Flat Rate Cardboard Envelope |  12.50 x 9.50 x 0.75 in |
    | USPS_FlatRateEnvelope | Flat Rate Envelope |  12.50 x 9.50 x 0.75 in |
    | USPS_FlatRateGiftCardEnvelope | Flat Rate Gift Card Envelope |  10.00 x 7.00 x 0.75 in |
    | USPS_FlatRateLegalEnvelope | Flat Rate Legal Envelope |  15.00 x 9.50 x 0.75 in |
    | USPS_FlatRatePaddedEnvelope | Flat Rate Padded Envelope |  12.50 x 9.50 x 1.00 in |
    | USPS_FlatRateWindowEnvelope | Flat Rate Window Envelope |  10.00 x 5.00 x 0.75 in |
    | USPS_IrregularParcel | Irregular Parcel |  0.00 x 0.00 x 0.00 in |
    | USPS_LargeFlatRateBoardGameBox | Large Flat Rate Board Game Box |  24.06 x 11.88 x 3.13 in |
    | USPS_LargeFlatRateBox | Large Flat Rate Box |  12.25 x 12.25 x 6.00 in |
    | USPS_APOFlatRateBox | APO/FPO/DPO Large Flat Rate Box |  12.25 x 12.25 x 6.00 in |
    | USPS_LargeVideoFlatRateBox | Flat Rate Large Video Box (Int&#39;l only) |  9.60 x 6.40 x 2.20 in |
    | USPS_MediumFlatRateBox1 | Medium Flat Rate Box 1 |  11.25 x 8.75 x 6.00 in |
    | USPS_MediumFlatRateBox2 | Medium Flat Rate Box 2 |  14.00 x 12.00 x 3.50 in |
    | USPS_RegionalRateBoxA1 | Regional Rate Box A1 |  10.13 x 7.13 x 5.00 in |
    | USPS_RegionalRateBoxA2 | Regional Rate Box A2 |  13.06 x 11.06 x 2.50 in |
    | USPS_RegionalRateBoxB1 | Regional Rate Box B1 |  12.25 x 10.50 x 5.50 in |
    | USPS_RegionalRateBoxB2 | Regional Rate Box B2 |  16.25 x 14.50 x 3.00 in |
    | USPS_SmallFlatRateBox | Small Flat Rate Box |  8.69 x 5.44 x 1.75 in |
    | USPS_SmallFlatRateEnvelope | Small Flat Rate Envelope |  10.00 x 6.00 x 4.00 in |
    | USPS_SoftPack | Soft Pack Padded Envelope |  Length and width defined in the Parcel|
    """
    USPS_FLAT_RATE_CARDBOARD_ENVELOPE = 'USPS_FlatRateCardboardEnvelope'
    USPS_FLAT_RATE_ENVELOPE = 'USPS_FlatRateEnvelope'
    USPS_FLAT_RATE_GIFT_CARD_ENVELOPE = 'USPS_FlatRateGiftCardEnvelope'
    USPS_FLAT_RATE_LEGAL_ENVELOPE = 'USPS_FlatRateLegalEnvelope'
    USPS_FLAT_RATE_PADDED_ENVELOPE = 'USPS_FlatRatePaddedEnvelope'
    USPS_FLAT_RATE_WINDOW_ENVELOPE = 'USPS_FlatRateWindowEnvelope'
    USPS_IRREGULAR_PARCEL = 'USPS_IrregularParcel'
    USPS_LARGE_FLAT_RATE_BOARD_GAME_BOX = 'USPS_LargeFlatRateBoardGameBox'
    USPS_LARGE_FLAT_RATE_BOX = 'USPS_LargeFlatRateBox'
    USPS_APO_FLAT_RATE_BOX = 'USPS_APOFlatRateBox'
    USPS_LARGE_VIDEO_FLAT_RATE_BOX = 'USPS_LargeVideoFlatRateBox'
    USPS_MEDIUM_FLAT_RATE_BOX1 = 'USPS_MediumFlatRateBox1'
    USPS_MEDIUM_FLAT_RATE_BOX2 = 'USPS_MediumFlatRateBox2'
    USPS_REGIONAL_RATE_BOX_A1 = 'USPS_RegionalRateBoxA1'
    USPS_REGIONAL_RATE_BOX_A2 = 'USPS_RegionalRateBoxA2'
    USPS_REGIONAL_RATE_BOX_B1 = 'USPS_RegionalRateBoxB1'
    USPS_REGIONAL_RATE_BOX_B2 = 'USPS_RegionalRateBoxB2'
    USPS_SMALL_FLAT_RATE_BOX = 'USPS_SmallFlatRateBox'
    USPS_SMALL_FLAT_RATE_ENVELOPE = 'USPS_SmallFlatRateEnvelope'
    USPS_SOFT_PACK = 'USPS_SoftPack'



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelAPGEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | epacket | ePacket|
    | epacket_plus | ePacket Plus|
    | eparcel_premium | eParcel premium|
    | apg_eparcel_expedited | eParcel Expedited|
    """
    EPACKET = 'epacket'
    EPACKET_PLUS = 'epacket_plus'
    EPARCEL_PREMIUM = 'eparcel_premium'
    APG_EPARCEL_EXPEDITED = 'apg_eparcel_expedited'



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelMondialRelayEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | mondial_relay_pointrelais | Point Relais|
    """
    MONDIAL_RELAY_POINTRELAIS = 'mondial_relay_pointrelais'



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from .addressimporter import AddressImporter
from .customsdeclarationb13afilingoptionenum import CustomsDeclarationB13AFilingOptionEnum
from .customsdeclarationcontentstypeenum import CustomsDeclarationContentsTypeEnum
from .customsdeclarationeelpfcenum import CustomsDeclarationEelPfcEnum
from .customsdeclarationincotermenum import CustomsDeclarationIncotermEnum
from .customsdeclarationnondeliveryoptionenum import CustomsDeclarationNonDeliveryOptionEnum
from .customsexporteridentification import CustomsExporterIdentification
from .customsitemcreaterequest import CustomsItemCreateRequest
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from shippo import utils
from typing import List, Optional


class CustomsDeclarationCreateRequestType(str, Enum):
    r"""Party to be billed for duties."""
    SENDER = 'SENDER'
    RECIPIENT = 'RECIPIENT'
    THIRD_PARTY = 'THIRD_PARTY'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class CustomsDeclarationCreateRequestAddress:
    name: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('name'), 'exclude': lambda f: f is None }})
    r"""Name of the party to be billed for duties."""
    zip: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('zip'), 'exclude': lambda f: f is None }})
    r"""Postal code of the party to be billed for duties."""
    country: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('country'), 'exclude': lambda f: f is None }})
    r"""Country ISO code of account number to be billed."""
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class DutiesPayor:
    r"""Specifies who will pay the duties for the shipment. Only accepted for FedEx shipments."""
    account: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('account'), 'exclude': lambda f: f is None }})
    r"""Account number to be billed for duties."""
    type: Optional[CustomsDeclarationCreateRequestType] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type'), 'exclude': lambda f: f is None }})
    r"""Party to be billed for duties."""
    address: Optional[CustomsDeclarationCreateRequestAddress] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('address'), 'exclude': lambda f: f is None }})
    



@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class CustomsDeclarationCreateRequest:
    certify: bool = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('certify') }})
    r"""Expresses that the certify_signer has provided all information of this customs declaration truthfully."""
    certify_signer: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('certify_signer') }})
    r"""Name of the person who created the customs declaration and is responsible for the validity of all
    information provided.
    """
    contents_type: CustomsDeclarationContentsTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('contents_type') }})
    items: List[CustomsItemCreateRequest] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('items') }})
    non_delivery_option: CustomsDeclarationNonDeliveryOptionEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('non_delivery_option') }})
    aes_itn: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('aes_itn'), 'exclude': lambda f: f is None }})
    r"""**required if eel_pfc is `AES_ITN`**<br>
    AES / ITN reference of the shipment.
    """
    b13a_filing_option: Optional[CustomsDeclarationB13AFilingOptionEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('b13a_filing_option'), 'exclude': lambda f: f is None }})
    b13a_number: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('b13a_number'), 'exclude': lambda f: f is None }})
    r"""**must be provided if and only if b13a_filing_option is provided**<br>
    Represents:<br> the Proof of Report (POR) Number when b13a_filing_option is `FILED_ELECTRONICALLY`;<br> 
    the Summary ID Number when b13a_filing_option is `SUMMARY_REPORTING`;<br> 
    or the Exemption Number when b13a_filing_option is `NOT_REQUIRED`.
    """
    certificate: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('certificate'), 'exclude': lambda f: f is None }})
    r"""Certificate reference of the shipment."""
    commercial_invoice: Optional[bool] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('commercial_invoice'), 'exclude': lambda f: f is None }})
    contents_explanation: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('contents_explanation'), 'exclude': lambda f: f is None }})
    r"""**required if contents_type is `OTHER`**<br>
    Explanation of the type of goods of the shipment.
    """
    disclaimer: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('disclaimer'), 'exclude': lambda f: f is None }})
    r"""Disclaimer for the shipment and customs information that have been provided."""
    duties_payor: Optional[DutiesPayor] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('duties_payor'), 'exclude': lambda f: f is None }})
    r"""Specifies who will pay the duties for the shipment. Only accepted for FedEx shipments."""
    exporter_identification: Optional[CustomsExporterIdentification] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('exporter_identification'), 'exclude': lambda f: f is None }})
    r"""Additional exporter identification that may be required to ship in certain countries"""
    exporter_reference: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('exporter_reference'), 'exclude': lambda f: f is None }})
    r"""Exporter reference of an export shipment."""
    importer_reference: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('importer_reference'), 'exclude': lambda f: f is None }})
    r"""Importer reference of an import shipment."""
    is_vat_collected: Optional[bool] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('is_vat_collected'), 'exclude': lambda f: f is None }})
    r"""Indicates whether the shipment's destination VAT has been collected. May be required for some destinations."""
    invoice: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('invoice'), 'exclude': lambda f: f is None }})
    r"""Invoice reference of the shipment."""
    license: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('license'), 'exclude': lambda f: f is None }})
    r"""License reference of the shipment."""
    metadata: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('metadata'), 'exclude': lambda f: f is None }})
    r"""A string of up to 100 characters that can be filled with any additional information you
    want to attach to the object.
    """
    notes: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('notes'), 'exclude': lambda f: f is None }})
    r"""Additional notes to be included in the customs declaration."""
    address_importer: Optional[AddressImporter] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('address_importer'), 'exclude': lambda f: f is None }})
    r"""Object that represents the address of the importer"""
    eel_pfc: Optional[CustomsDeclarationEelPfcEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('eel_pfc'), 'exclude': lambda f: f is None }})
    incoterm: Optional[CustomsDeclarationIncotermEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('incoterm'), 'exclude': lambda f: f is None }})
    test: Optional[bool] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('test'), 'exclude': lambda f: f is None }})
    




"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from shippo import utils


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class FedExConnectExistingOwnAccountParameters:
    first_name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('first_name') }})
    r"""First name of the account holder"""
    last_name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('last_name') }})
    r"""Last name of the account holder"""
    phone_number: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('phone_number') }})
    r"""Phone number of the account holder"""
    from_address_st: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('from_address_st') }})
    r"""Street address of the account holder"""
    from_address_city: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('from_address_city') }})
    r"""City of the account holder"""
    from_address_state: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('from_address_state') }})
    r"""State of the account holder"""
    from_address_zip: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('from_address_zip') }})
    r"""Zip code of the account holder"""
    from_address_country_iso2: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('from_address_country_iso2') }})
    r"""Country of the account holder"""
    




"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .addshipmentstobatch import *
from .createaddress import *
from .createbatch import *
from .createcarrieraccount import *
from .createcustomsdeclaration import *
from .createcustomsitem import *
from .createliverate import *
from .createmanifest import *
from .createorder import *
from .createparcel import *
from .createpickup import *
from .createrefund import *
from .createservicegroup import *
from .createshipment import *
from .createshippoaccount import *
from .createtrack import *
from .createtransaction import *
from .createuserparceltemplate import *
from .deletedefaultparceltemplate import *
from .deleteservicegroup import *
from .deleteuserparceltemplate import *
from .deletewebhook import *
from .getaddress import *
from .getbatch import *
from .getcarrieraccount import *
from .getcarrierparceltemplate import *
from .getcarrierregistrationstatus import *
from .getcustomsdeclaration import *
from .getcustomsitem import *
from .getdefaultparceltemplate import *
from .getmanifest import *
from .getorder import *
from .getparcel import *
from .getrate import *
from .getrefund import *
from .getshipment import *
from .getshippoaccount import *
from .gettrack import *
from .gettransaction import *
from .getuserparceltemplate import *
from .getwebhook import *
from .initiateoauth2signin import *
from .listaddresses import *
from .listcarrieraccounts import *
from .listcarrierparceltemplates import *
from .listcustomsdeclarations import *
from .listcustomsitems import *
from .listmanifests import *
from .listorders import *
from .listparcels import *
from .listrefunds import *
from .listservicegroups import *
from .listshipmentrates import *
from .listshipmentratesbycurrencycode import *
from .listshipments import *
from .listshippoaccounts import *
from .listtransactions import *
from .listuserparceltemplates import *
from .purchasebatch import *
from .registercarrieraccount import *
from .removeshipmentsfrombatch import *
from .updatecarrieraccount import *
from .updatedefaultparceltemplate import *
from .updateservicegroup import *
from .updateshippoaccount import *
from .updateuserparceltemplate import *
from .updatewebhook import *
from .validateaddress import *

__all__ = ["AddShipmentsToBatchGlobals","AddShipmentsToBatchRequest","Carrier","CreateAddressGlobals","CreateBatchGlobals","CreateCarrierAccountGlobals","CreateCustomsDeclarationGlobals","CreateCustomsItemGlobals","CreateLiveRateGlobals","CreateManifestGlobals","CreateOrderGlobals","CreateParcelGlobals","CreateParcelRequestBody","CreatePickupGlobals","CreateRefundGlobals","CreateServiceGroupGlobals","CreateShipmentGlobals","CreateShippoAccountGlobals","CreateTrackGlobals","CreateTransactionGlobals","CreateTransactionRequestBody","CreateUserParcelTemplateGlobals","DeleteDefaultParcelTemplateGlobals","DeleteDefaultParcelTemplateRequest","DeleteServiceGroupGlobals","DeleteServiceGroupRequest","DeleteUserParcelTemplateGlobals","DeleteUserParcelTemplateRequest","DeleteWebhookRequest","GetAddressGlobals","GetAddressRequest","GetBatchGlobals","GetBatchRequest","GetCarrierAccountGlobals","GetCarrierAccountRequest","GetCarrierParcelTemplateGlobals","GetCarrierParcelTemplateRequest","GetCarrierRegistrationStatusGlobals","GetCarrierRegistrationStatusRequest","GetCustomsDeclarationGlobals","GetCustomsDeclarationRequest","GetCustomsItemGlobals","GetCustomsItemRequest","GetDefaultParcelTemplateGlobals","GetDefaultParcelTemplateRequest","GetManifestGlobals","GetManifestRequest","GetOrderGlobals","GetOrderRequest","GetParcelGlobals","GetParcelRequest","GetRateGlobals","GetRateRequest","GetRefundGlobals","GetRefundRequest","GetShipmentGlobals","GetShipmentRequest","GetShippoAccountGlobals","GetShippoAccountRequest","GetTrackGlobals","GetTrackRequest","GetTransactionGlobals","GetTransactionRequest","GetUserParcelTemplateGlobals","GetUserParcelTemplateRequest","GetWebhookRequest","Include","InitiateOauth2SigninGlobals","InitiateOauth2SigninRequest","InitiateOauth2SigninResponse","ListAddressesGlobals","ListAddressesRequest","ListCarrierAccountsGlobals","ListCarrierAccountsRequest","ListCarrierParcelTemplatesGlobals","ListCarrierParcelTemplatesRequest","ListCustomsDeclarationsGlobals","ListCustomsDeclarationsRequest","ListCustomsItemsGlobals","ListCustomsItemsRequest","ListManifestsGlobals","ListManifestsRequest","ListOrdersGlobals","ListOrdersRequest","ListParcelsGlobals","ListParcelsRequest","ListRefundsGlobals","ListRefundsRequest","ListServiceGroupsGlobals","ListServiceGroupsRequest","ListShipmentRatesByCurrencyCodeGlobals","ListShipmentRatesByCurrencyCodeRequest","ListShipmentRatesGlobals","ListShipmentRatesRequest","ListShipmentsGlobals","ListShipmentsRequest","ListShippoAccountsGlobals","ListShippoAccountsRequest","ListTransactionsGlobals","ListTransactionsRequest","ListUserParcelTemplatesGlobals","ListUserParcelTemplatesRequest","PurchaseBatchGlobals","PurchaseBatchRequest","RegisterCarrierAccountGlobals","RegisterCarrierAccountRequestBody","RemoveShipmentsFromBatchGlobals","RemoveShipmentsFromBatchRequest","UpdateCarrierAccountGlobals","UpdateCarrierAccountRequest","UpdateDefaultParcelTemplateGlobals","UpdateServiceGroupGlobals","UpdateShippoAccountGlobals","UpdateShippoAccountRequest","UpdateUserParcelTemplateGlobals","UpdateUserParcelTemplateRequest","UpdateWebhookRequest","ValidateAddressGlobals","ValidateAddressRequest"]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ServiceLevelCanadaPostEnum(str, Enum):
    r"""|Token | Service name|
    |:---|:---|
    | canada_post_regular_parcel | Regular Parcel|
    | canada_post_expedited_parcel | Expedited Parcel|
    | canada_post_priority | Priority|
    | canada_post_xpresspost | Xpresspost|
    | canada_post_xpresspost_international | Xpresspost International|
    | canada_post_xpresspost_usa | Xpresspost USA|
    | canada_post_expedited_parcel_usa | Expedited Parcel USA|
    | canada_post_tracked_packet_usa | Tracked Packet USA|
    | canada_post_small_packet_usa_air | Small Packet USA Air|
    | canada_post_tracked_packet_international | Tracked Packet International|
    | canada_post_small_packet_international_air | Small Package International Air|
    """
    CANADA_POST_REGULAR_PARCEL = 'canada_post_regular_parcel'
    CANADA_POST_EXPEDITED_PARCEL = 'canada_post_expedited_parcel'
    CANADA_POST_PRIORITY = 'canada_post_priority'
    CANADA_POST_XPRESSPOST = 'canada_post_xpresspost'
    CANADA_POST_XPRESSPOST_INTERNATIONAL = 'canada_post_xpresspost_international'
    CANADA_POST_XPRESSPOST_USA = 'canada_post_xpresspost_usa'
    CANADA_POST_EXPEDITED_PARCEL_USA = 'canada_post_expedited_parcel_usa'
    CANADA_POST_TRACKED_PACKET_USA = 'canada_post_tracked_packet_usa'
    CANADA_POST_SMALL_PACKET_USA_AIR = 'canada_post_small_packet_usa_air'
    CANADA_POST_TRACKED_PACKET_INTERNATIONAL = 'canada_post_tracked_packet_international'
    CANADA_POST_SMALL_PACKET_INTERNATIONAL_AIR = 'canada_post_small_packet_international_air'



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from dataclasses_json import Undefined, dataclass_json
from shippo import utils


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class CarrierAccountCanadaPostCreateParameters:
    canada_post_terms: bool = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('canada_post_terms') }})
    r"""Whether or not the user agrees to Canada Post's terms. If passed in as false, request will fail with error 400"""
    company: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('company') }})
    email: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('email') }})
    full_name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('full_name') }})
    phone: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('phone') }})
    r"""Needs to be a valid phone number and cannot be null"""
    

